clc;
clear all;
close all;

%% Data reading...

cfg.address_pointing = 'D:\MATLAB\tremor_data\Surgeon Pointing\Data\';
cfg.address_pointing_output = 'D:\MATLAB\tremor_data\Surgeon Pointing\Output1\';

cfg.data_name_pointing = '_pointingxyzAI_mag1_force01_';

cfg.subject_name_surgeon = {'de' 'sh' 'so' 'we'};


%   Initial Parameters
cfg.Fs=250; cfg.Ts=1/cfg.Fs;

% Bandpass filter design
Fs=250; Ts=1/Fs; 
nyq_fs=1/(2*Ts);  %Nyquist frequency
cutoff1=1/nyq_fs*5;
cutoff2=1/nyq_fs*20;

[B,A]=butter(5,[cutoff1, cutoff2]);


cfg.mu0 =  7e-5:2e-6:9e-5; 
cfg.mu1 =  0.07:0.001:.08;
cfg.parameters.Fs=250;
%% surgeon pointing

for i = 1:length(cfg.subject_name_surgeon)
    data = eval (sprintf('textread(''%sS%s%s02.txt\'')', cfg.address_pointing,cfg.data_name_pointing,cfg.subject_name_surgeon{i}));
    
    data=data(1:7500,:);
    cfg.data = data(1:7500,2:5); cfg.data(:,1:3) = cfg.data(:,1:3)*1e-3; clear data;

    
    mismatch_pointing_surgeon = cell(length(cfg.subject_name_surgeon),length(cfg.mu0),length(cfg.mu1));
    mismatch_summary_pointing_surgeon = cell(length(cfg.subject_name_surgeon),length(cfg.mu0),length(cfg.mu1));
    
   cfg.data_bpfiltered=filtfilt(B,A,cfg.data);
    cfg.data_truncated =  cfg.data_bpfiltered (101:7101,:);
    
    cfg.parameters.t = 0:cfg.Ts:(size(cfg.data_truncated,1)-1)*cfg.Ts';   %  Time vector
    cfg.parameters.M = 1;                                                 % Number of harmonics
    
    
    for j = 1:length(cfg.mu0)
        for k= 1:length(cfg.mu1)
            disp(sprintf('Surgeon %d: mu0 = %d, m01 = %d',i, cfg.mu0(j),cfg.mu1(k)))
            cfg.parameters.mu0 = cfg.mu0(j);
            cfg.parameters.mu1 = cfg.mu1(k);

            cfg.WFLC1D  = WFLC1D(cfg.data_truncated,cfg.parameters);
            cfg.QWFLC3D = QWFLC3D(cfg.data_truncated,cfg.parameters);
            cfg.QWFLC4D = QWFLC4D(cfg.data_truncated,cfg.parameters);
            
            WFLC1D_out          = cfg.WFLC1D;
            QWFLC3D_out         = cfg.QWFLC3D;
            QWFLC4D_out         = cfg.QWFLC4D;

            filename = sprintf('%sPointing_WFLC1D_S%d_mu0_%d_mu1_%d.mat',cfg.address_pointing_output,i,j,k); save(filename,'WFLC1D_out');
            filename = sprintf('%sPointing_QWFLC3D_S%d_mu0_%d_mu1_%d.mat',cfg.address_pointing_output,i,j,k); save(filename,'QWFLC3D_out');
            filename = sprintf('%sPointing_QWFLC4D_S%d_mu0_%d_mu1_%d.mat',cfg.address_pointing_output,i,j,k); save(filename,'QWFLC4D_out');
            clear filename;
            
            [cfg.mismatch_pointing_surgeon{i,j,k}, cfg.mismatch_summary_pointing_surgeon{i,j,k}]= ...
                mismatch_cal(cfg.data_truncated,cfg.WFLC1D,cfg.QWFLC3D,cfg.QWFLC4D);
            % Add a routine to save outputs in different matlab data files with files
            % Name them according to ijk in a results folder
        end
    end
    
end

% averaging across subjects for mismatch_summary

for j = 1:length(cfg.mu0)
    for k= 1:length(cfg.mu1)
        mean_mismatch_pointing_surgeon(:,j,k) = mean(cell2mat(cfg.mismatch_summary_pointing_surgeon(:,j,k)));
        WFLC1D_pointing_surgeon_steadystate(j,k) = mean_mismatch_pointing_surgeon(1,j,k);
        QWFLC3D_pointing_surgeon_steadystate(j,k) = mean_mismatch_pointing_surgeon(2,j,k);
        QWFLC4D_pointing_surgeon_steadystate(j,k) = mean_mismatch_pointing_surgeon(3,j,k);
    end
end


filename = sprintf('%sMean_mismatch_SP.mat',cfg.address_pointing_output); save(filename,'mean_mismatch_pointing_surgeon');clear filename;
filename = sprintf('%sWFLC1D_SP_mismatch_SSE.mat',cfg.address_pointing_output); save(filename,'WFLC1D_pointing_surgeon_steadystate');clear filename;
filename = sprintf('%sQWFLC3D_SP_mismatch_SSE.mat',cfg.address_pointing_output); save(filename,'QWFLC3D_pointing_surgeon_steadystate');clear filename;
filename = sprintf('%sQWFLC4D_SP_mismatch_SSE.mat',cfg.address_pointing_output); save(filename,'QWFLC4D_pointing_surgeon_steadystate');clear filename;

figure (1) 
surf(cfg.mu0,cfg.mu1,WFLC1D_pointing_surgeon_steadystate)
hold on
surf(cfg.mu0,cfg.mu1,QWFLC3D_pointing_surgeon_steadystate)
hold on
surf(cfg.mu0,cfg.mu1,QWFLC4D_pointing_surgeon_steadystate)
axis square

saveas(gcf,[cfg.address_pointing_output,filesep,'Pointing_S'],'fig');

